# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-08-27 01:27
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_dpa_chile', '0002_comuna_region'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='comuna',
            name='id',
        ),
        migrations.RemoveField(
            model_name='provincia',
            name='id',
        ),
        migrations.RemoveField(
            model_name='region',
            name='id',
        ),
        migrations.AlterField(
            model_name='comuna',
            name='codigo',
            field=models.CharField(max_length=10, primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='provincia',
            name='codigo',
            field=models.CharField(max_length=10, primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='region',
            name='codigo',
            field=models.CharField(max_length=10, primary_key=True, serialize=False),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-08-27 01:22
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('django_dpa_chile', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='comuna',
            name='region',
            field=models.ForeignKey(default=None, on_delete=django.db.models.deletion.CASCADE, to='django_dpa_chile.Region'),
            preserve_default=False,
        ),
    ]
